"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _core = require("@material-ui/core");

var _gatsby = require("gatsby");

var _q3UiLocale = require("q3-ui-locale");

var _lodash = require("lodash");

var _BackgroundStyle = _interopRequireDefault(require("q3-admin/lib/components/BackgroundStyle"));

var _AdminPublicGateway = _interopRequireDefault(require("./AdminPublicGateway"));

var _useSiteMetaData = _interopRequireDefault(require("./useSiteMetaData"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useStyle = (0, _core.makeStyles)(theme => ({
  logo: ({
    invertLogo = false
  }) => {
    const output = {
      height: 75,
      maxHeight: 75,
      width: 290,
      display: 'block',
      [theme.breakpoints.down('md')]: {
        height: 65,
        maxHeight: 65,
        width: 250
      },
      '& img': {
        objectFit: 'contain',
        height: '100%',
        width: '100%'
      }
    };
    if (theme.palette.type === 'dark' && invertLogo) output.filter = 'invert(1) grayscale(100%)';
    return output;
  },
  container: {
    maxWidth: '85vw',
    width: 850,
    [theme.breakpoints.down('md')]: {
      width: '100%'
    },
    [theme.breakpoints.down('sm')]: {
      width: 'auto'
    }
  },
  photo: ({
    photo
  }) => ({
    backgroundColor: theme.palette.secondary.light,
    backgroundImage: (0, _lodash.isString)(photo) ? `url("${String(photo).replace(/\s/gi, '%20')}")` : undefined,
    backgroundSize: 'cover',
    backgroundPosition: 'center',
    backgroundRepeat: 'no-repeat',
    width: '100%',
    height: '100%',
    backgroundBlendMode: 'multiply',
    minHeight: '55vh'
  })
}));

const Copyright = () => {
  const {
    brand
  } = (0, _useSiteMetaData.default)();
  return brand ? /*#__PURE__*/_react.default.createElement(_core.Box, {
    display: "inline-block",
    mx: 1
  }, "\xA9", new Date().getFullYear(), " ", brand) : null;
}; // eslint-disable-next-line


const TextLink = ({
  href,
  text
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');
  return href ? /*#__PURE__*/_react.default.createElement(_core.Box, {
    display: "inline-block",
    mx: 1
  }, /*#__PURE__*/_react.default.createElement(_core.Link, {
    href: href,
    target: "_blank"
  }, t(text))) : null;
};

const PublicTemplate = ({
  children,
  ...rest
}) => {
  const {
    brand,
    cancellation,
    invertLogo,
    terms,
    privacy,
    logo,
    photo
  } = (0, _useSiteMetaData.default)({
    logo: '/logo.png',
    photo: '/background.jpg'
  });
  const cls = useStyle({
    photo,
    invertLogo
  });
  return /*#__PURE__*/_react.default.createElement(_AdminPublicGateway.default, rest, /*#__PURE__*/_react.default.createElement(_BackgroundStyle.default, null), /*#__PURE__*/_react.default.createElement(_core.Box, {
    alignItems: "center",
    component: "article",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    width: "100%"
  }, /*#__PURE__*/_react.default.createElement(_core.Box, {
    component: "header",
    mt: "2vh",
    mb: 1,
    textAlign: "center"
  }, /*#__PURE__*/_react.default.createElement(_gatsby.Link, {
    to: "/",
    className: cls.logo
  }, /*#__PURE__*/_react.default.createElement("img", {
    alt: brand,
    src: logo
  }))), /*#__PURE__*/_react.default.createElement(_core.Paper, {
    className: cls.container
  }, /*#__PURE__*/_react.default.createElement(_core.Grid, {
    container: true,
    spacing: 1
  }, /*#__PURE__*/_react.default.createElement(_core.Hidden, {
    smDown: true
  }, /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    xs: 6
  }, /*#__PURE__*/_react.default.createElement(_core.Box, {
    className: cls.photo
  }))), /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    md: 6,
    xs: 12
  }, /*#__PURE__*/_react.default.createElement(_core.Box, {
    alignItems: "center",
    height: "100%",
    display: "flex",
    p: 2
  }, children)))), /*#__PURE__*/_react.default.createElement(_core.Box, {
    maxWidth: "75vw",
    component: "footer",
    mt: 2,
    textAlign: "center"
  }, /*#__PURE__*/_react.default.createElement("small", null, /*#__PURE__*/_react.default.createElement(Copyright, null), /*#__PURE__*/_react.default.createElement(TextLink, {
    href: terms,
    text: "termsAndConditions"
  }), /*#__PURE__*/_react.default.createElement(TextLink, {
    href: privacy,
    text: "privacyPolicy"
  }), /*#__PURE__*/_react.default.createElement(TextLink, {
    href: cancellation,
    text: "cancellationPolicy"
  })))));
};

PublicTemplate.defaultProps = {
  children: null
};
PublicTemplate.propTypes = {
  children: _propTypes.default.node
};
var _default = PublicTemplate;
exports.default = _default;